package sun.misc;

import java.text.MessageFormat;
import java.util.StringTokenizer;
import java.util.jar.Attributes;
import java.util.ResourceBundle;

public class ExtensionInfo
{
    public static final int COMPATIBLE = 0;
    public static final int REQUIRE_SPECIFICATION_UPGRADE = 1;
    public static final int REQUIRE_IMPLEMENTATION_UPGRADE = 2;
    public static final int REQUIRE_VENDOR_SWITCH = 3;
    public static final int INCOMPATIBLE = 4;
    public String title;
    public String name;
    public String specVersion;
    public String specVendor;
    public String implementationVersion;
    public String vendor;
    public String vendorId;
    public String url;
    private static final ResourceBundle rb;
    
    public ExtensionInfo() {
    }
    
    public ExtensionInfo(String str, Attributes attributes) throws NullPointerException {
        String string;
        if (str != null) {
            string = str + "-";
        }
        else {
            string = "";
        }
        this.name = attributes.getValue(string + Attributes.Name.EXTENSION_NAME.toString());
        if (this.name != null) {
            this.name = this.name.trim();
        }
        this.title = attributes.getValue(string + Attributes.Name.SPECIFICATION_TITLE.toString());
        if (this.title != null) {
            this.title = this.title.trim();
        }
        this.specVersion = attributes.getValue(string + Attributes.Name.SPECIFICATION_VERSION.toString());
        if (this.specVersion != null) {
            this.specVersion = this.specVersion.trim();
        }
        this.specVendor = attributes.getValue(string + Attributes.Name.SPECIFICATION_VENDOR.toString());
        if (this.specVendor != null) {
            this.specVendor = this.specVendor.trim();
        }
        this.implementationVersion = attributes.getValue(string + Attributes.Name.IMPLEMENTATION_VERSION.toString());
        if (this.implementationVersion != null) {
            this.implementationVersion = this.implementationVersion.trim();
        }
        this.vendor = attributes.getValue(string + Attributes.Name.IMPLEMENTATION_VENDOR.toString());
        if (this.vendor != null) {
            this.vendor = this.vendor.trim();
        }
        this.vendorId = attributes.getValue(string + Attributes.Name.IMPLEMENTATION_VENDOR_ID.toString());
        if (this.vendorId != null) {
            this.vendorId = this.vendorId.trim();
        }
        this.url = attributes.getValue(string + Attributes.Name.IMPLEMENTATION_URL.toString());
        if (this.url != null) {
            this.url = this.url.trim();
        }
    }
    
    public int isCompatibleWith(ExtensionInfo extensionInfo) {
        if (this.name == null || extensionInfo.name == null) {
            return 4;
        }
        if (this.name.compareTo(extensionInfo.name) == 0) {
            if (this.specVersion == null || extensionInfo.specVersion == null) {
                return 0;
            }
            if (this.compareExtensionVersion(this.specVersion, extensionInfo.specVersion) < 0) {
                if (this.vendorId != null && extensionInfo.vendorId != null && this.vendorId.compareTo(extensionInfo.vendorId) != 0) {
                    return 3;
                }
                return 1;
            }
            else {
                if (this.vendorId != null && extensionInfo.vendorId != null) {
                    if (this.vendorId.compareTo(extensionInfo.vendorId) != 0) {
                        return 3;
                    }
                    if (this.implementationVersion != null && extensionInfo.implementationVersion != null && this.compareExtensionVersion(this.implementationVersion, extensionInfo.implementationVersion) < 0) {
                        return 2;
                    }
                }
                return 0;
            }
        }
        else {
            return 4;
        }
    }
    
    @Override
    public String toString() {
        return "Extension : title(" + this.title + "), name(" + this.name + "), spec vendor(" + this.specVendor + "), spec version(" + this.specVersion + "), impl vendor(" + this.vendor + "), impl vendor id(" + this.vendorId + "), impl version(" + this.implementationVersion + "), impl url(" + this.url + ")";
    }
    
    private int compareExtensionVersion(String lowerCase, String lowerCase2) throws NumberFormatException {
        lowerCase = lowerCase.toLowerCase();
        lowerCase2 = lowerCase2.toLowerCase();
        return this.strictCompareExtensionVersion(lowerCase, lowerCase2);
    }
    
    private int strictCompareExtensionVersion(String str, String s) throws NumberFormatException {
        if (str.equals(s)) {
            return 0;
        }
        StringTokenizer stringTokenizer = new StringTokenizer(str, ".,");
        StringTokenizer stringTokenizer2 = new StringTokenizer(s, ".,");
        int convertToken = 0;
        int convertToken2 = 0;
        if (stringTokenizer.hasMoreTokens()) {
            convertToken = this.convertToken(stringTokenizer.nextToken().toString());
        }
        if (stringTokenizer2.hasMoreTokens()) {
            convertToken2 = this.convertToken(stringTokenizer2.nextToken().toString());
        }
        if (convertToken > convertToken2) {
            return 1;
        }
        if (convertToken2 > convertToken) {
            return -1;
        }
        int index = str.indexOf(".");
        int index2 = s.indexOf(".");
        if (index == -1) {
            index = str.length() - 1;
        }
        if (index2 == -1) {
            index2 = s.length() - 1;
        }
        return this.strictCompareExtensionVersion(str.substring(index + 1), s.substring(index2 + 1));
    }
    
    private int convertToken(String s) {
        if (s == null || s.equals("")) {
            return 0;
        }
        int n = 0;
        int length = s.length();
        String format = new MessageFormat(ExtensionInfo.rb.getString("optpkg.versionerror")).format(new Object[] { this.name });
        int index = s.indexOf("-");
        int index2 = s.indexOf("_");
        if (index == -1 && index2 == -1) {
            try {
                return Integer.parseInt(s) * 100;
            }
            catch (NumberFormatException ex4) {
                System.out.println(format);
                return 0;
            }
        }
        else {
            if (index2 != -1) {
                int int2;
                int n3;
                try {
                    int2 = Integer.parseInt(s.substring(0, index2));
                    int char1 = s.charAt(length - 1);
                    if (Character.isLetter((char)char1)) {
                        int numericValue = Character.getNumericValue((char)char1);
                        n3 = Integer.parseInt(s.substring(index2 + 1, length - 1));
                        if (numericValue >= Character.getNumericValue('a') && numericValue <= Character.getNumericValue('z')) {
                            n = n3 * 100 + numericValue;
                        }
                        else {
                            n = 0;
                            System.out.println(format);
                        }
                    }
                    else {
                        n3 = Integer.parseInt(s.substring(index2 + 1, length));
                    }
                }
                catch (NumberFormatException ex3) {
                    System.out.println(format);
                    return 0;
                }
                return int2 * 100 + (n3 + n);
            }
            int int1;
            try {
                int1 = Integer.parseInt(s.substring(0, index));
            }
            catch (NumberFormatException ex) {
                System.out.println(format);
                return 0;
            }
            String substring = s.substring(index + 1);
            String s2 = "";
            int n2 = 0;
            if (substring.indexOf("ea") != -1) {
                s2 = substring.substring(2);
                n2 = 50;
            }
            else if (substring.indexOf("alpha") != -1) {
                s2 = substring.substring(5);
                n2 = 40;
            }
            else if (substring.indexOf("beta") != -1) {
                s2 = substring.substring(4);
                n2 = 30;
            }
            else if (substring.indexOf("rc") != -1) {
                s2 = substring.substring(2);
                n2 = 20;
            }
            if (s2 == null || s2.equals("")) {
                return int1 * 100 - n2;
            }
            try {
                return int1 * 100 - n2 + Integer.parseInt(s2);
            }
            catch (NumberFormatException ex2) {
                System.out.println(format);
                return 0;
            }
        }
    }
    
    static {
        rb = ResourceBundle.getBundle("sun.misc.resources.Messages");
    }
}
